@@ -1,16 +1,14 @@
 
 import hashlib
-import urllib
-from urllib.parse import urlparse
-from urllib.request import unquote
 from Crypto.Cipher import AES
-from base64 import b64decode
-from base64 import b64encode
+from Crypto.Util.Padding import pad, unpad
 
-VERSION = '0.1.15'
+
+VERSION = '0.1.16'
 appKey = '434a209a5ce141c3b726de067835d7f0'
 signKey = 'xhdiwjnchekd4d512chdjx5d8e4c394D2D7S'
 
+
 class security:
 
     def __init__(self):
@@ -19,32 +17,24 @@ class security:
         self.blockSize = 16
         self.encKey = self.enc_key()
         self.dynamicKey = self.dynamic_key()
-         
 
     def aes_decrypt(self, raw):
         cipher = AES.new(self.encKey, AES.MODE_ECB)
         decrypted = cipher.decrypt(bytes(raw))
 
         # Remove the padding
-        decrypted = self._unpad(decrypted)   
+        decrypted = unpad(decrypted, self.blockSize)
 
         return decrypted
 
     def aes_encrypt(self, raw):
         # Make sure to pad the data
-        self._pad(raw)
-        
+        raw = pad(raw, self.blockSize)
+
         cipher = AES.new(self.encKey, AES.MODE_ECB)
         encrypted = cipher.encrypt(bytes(raw))
-            
-        return encrypted
 
-    def _pad(self, s):
-        pad = self.blockSize - (len(s) % self.blockSize)
-        s.extend([pad] * pad)
-       
-    def _unpad(self, s):
-        return s[:-s[-1]]
+        return encrypted
 
     def enc_key(self):
         m = hashlib.md5()
